:og:description: Mantelo is a super small yet super powerful Python library for interacting with the Keycloak Admin API.

.. meta::
   :description: Mantelo is a super small yet super powerful Python library for interacting with the Keycloak Admin API.

Mantelo: A Keycloak Admin REST Api Client for Python
=====================================================

✨ MANTELO is a super small yet super powerful tool for interacting with the Keycloak Admin API ✨.

   Mantelo [manˈtelo], from German "*Mantel*", from Late Latin "*mantum*" means "*cloak*" in Esperanto.

It stays always **fresh** and **complete** because it does not implement or wrap any endpoint.
Instead, it offers an object-oriented interface to the Keycloak ReSTful API. Acting as a wrapper
around the well-known `requests <https://requests.readthedocs.io/en/latest/>`_ library and using
slumber under the hood, it abstracts all the boring stuff such as authentication (tokens and refresh
tokens), URL handling, serialization, and the processing of requests. This magic is made possible by
the excellent `slumber <https://slumber.readthedocs.io/>`_ library.

⮕ Any endpoint your Keycloak supports, mantelo supports!

-------------------

.. toctree::
   :maxdepth: 2
   :caption: Contents

   00-getting_started
   01-authentication
   02-making-calls
   03-examples
   04-faq
   90-api

-------------------

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
